@@ -3,11 +3,11 @@ package DBIx::dbMan::Extension::CmdConnections;
 use strict;
 use base 'DBIx::dbMan::Extension';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 1;
 
-sub IDENTIFICATION { return "000001-000004-000006"; }
+sub IDENTIFICATION { return "000001-000004-000007"; }
 
 sub preference { return 2000; }
 
@@ -48,7 +48,7 @@ sub handle_action {
 			} else {
 				$action{what} = 'all';
 			}
-		} elsif ($action{cmd} =~ /^create\s+(permanent\s+)?connection\s+(\S+)\s+as\s+(\S+?):\s*(.*?)\s+login\s+(\S+)(?:\s+(password\s+(\S+)|nopassword))?(\s+autoopen)?$/i) {
+		} elsif ($action{cmd} =~ /^create\s+(permanent\s+)?connection\s+(\S+)\s+as\s+(\S+?):\s*(.*?)\s+login\s+(\S+)(?:\s+(password\s+(\S+)|nopassword))?(\s+config\s+(\S+?))?(\s+autoopen)?$/i) {
 			# as driver:dsn login user [password password]
 			$action{action} = 'CONNECTION';
 			$action{operation} = 'create';
@@ -65,7 +65,8 @@ sub handle_action {
 					$action{password} = $obj->{-interface}->get_password('Password: ');
 				}
 			}
-			$action{auto_login} = 'yes' if $8;
+			$action{config} = $9 || '';
+			$action{auto_login} = 'yes' if $10;
 		} elsif ($action{cmd} =~ /^drop\s+(permanent\s+)?connection\s+(\S+)$/i) {
 			$action{action} = 'CONNECTION';
 			$action{operation} = 'drop';
@@ -85,7 +86,7 @@ sub cmdhelp {
 		'CLOSE <connection_name>' => 'Close specific connection',
 		'USE <connection_name>' => 'Set selected connecection as current',
 		'SHOW [ACTIVE|ALL] CONNECTIONS' => 'Show list of active/all connections',
-		'CREATE [PERMANENT] CONNECTION <name> AS <driver>:<dsn> LOGIN <login> [PASSWORD <password> | NOPASSWORD] [AUTOOPEN]' => 'Creating new connection',
+		'CREATE [PERMANENT] CONNECTION <name> AS <driver>:<dsn> LOGIN <login> [PASSWORD <password> | NOPASSWORD] [CONFIG <config>] [AUTOOPEN]' => 'Creating new connection',
 		'DROP [PERMANENT] CONNECTION <name>' => 'Droping specific connection'
 		];
 }
@@ -106,7 +107,8 @@ sub driverlist {
 sub cmdcomplete {
 	my ($obj,$text,$line,$start) = @_;
 	return $obj->connectionlist(lc $1) if $line =~ /^\s*(REOPEN|OPEN|CLOSE|USE|DROP\s+(PERMANENT\s+)?CONNECTION)\s+\S*$/i;
-	return qw/AUTOOPEN/ if $line =~ /^\s*CREATE\s+(PERMANENT\s+)?CONNECTION\s+\S+\s+AS\s+\S+:\s*\S*\s+LOGIN\s+\S+\s+(NO)?PASSWORD\s+\S+\s+\S*$/i;
+	return qw/AUTOOPEN/ if $line =~ /^\s*CREATE\s+(PERMANENT\s+)?CONNECTION\s+\S+\s+AS\s+\S+:\s*\S*\s+LOGIN\s+\S+\s+(NOPASSWORD|PASSWORD\s+\S+)\s+CONFIG\s+\S+\s+\S*$/i;
+	return qw/CONFIG AUTOOPEN/ if $line =~ /^\s*CREATE\s+(PERMANENT\s+)?CONNECTION\s+\S+\s+AS\s+\S+:\s*\S*\s+LOGIN\s+\S+\s+(NOPASSWORD|PASSWORD\s+\S+)\s+\S*$/i;
 	return qw/PASSWORD NOPASSWORD/ if $line =~ /^\s*CREATE\s+(PERMANENT\s+)?CONNECTION\s+\S+\s+AS\s+\S+:\s*\S*\s+LOGIN\s+\S+\s+\S*$/i;
 	return $obj->driverlist if $line =~ /^\s*CREATE\s+(PERMANENT\s+)?CONNECTION\s+\S+\s+AS\s+\S*$/i;
 	return qw/LOGIN/ if $line =~ /^\s*CREATE\s+(PERMANENT\s+)?CONNECTION\s+\S+\s+AS\s+\S+:\s*\S*\s+\S*$/i;
