@@ -1,16 +1,14 @@
 package DBIx::dbMan::Extension::ShowTablesOracle;
 
 use strict;
-use vars qw/$VERSION @ISA/;
-use DBIx::dbMan::Extension;
+use base 'DBIx::dbMan::Extension';
 use Text::FormatTable;
 
-$VERSION = '0.05';
-@ISA = qw/DBIx::dbMan::Extension/;
+our $VERSION = '0.06';
 
 1;
 
-sub IDENTIFICATION { return "000001-000039-000005"; }
+sub IDENTIFICATION { return "000001-000039-000006"; }
 
 sub preference { return 50; }
 
